<?php
$lan = array(
 'This page can only be called from the commandline' => 'Esta p&aacute;gina s&oacute; pode ser acessada pela linha de comando',
 'Getting and Parsing the RSS sources' => 'Obtendo e Categorizando as fontes RSS',
 'Rss Errors' => 'Erros do RSS',
 'Rss Results' => 'Resultados do RSS',
 'Rss Failure report' => 'Relat&oacute;rio de Falhas do RSS',
 'Parsing' => 'Categorizando',
 'ok' => 'ok',
 'failed' => 'falhou',
 'Process Killed by other process' => 'Processo interrompido por outro processo',
 'items' => '&iacute;tens',
 'new items' => 'novos &iacute;tens',
'Nothing to do' => 'N&atilde;o h&aacute; o que fazer',
);
?>
